<div class="video">
  <video width="100%" height="auto" preload="{{ preload }}"
    {% if poster is not none %}poster="{{ url_for('get_file', jobid=jobid, filename=poster) }}"{% endif %} controls>
  <source src="{{ url_for('get_file', jobid=jobid, filename=filename) }}" type="video/mp4">
  Your browser does not support the video tag.
  </video>
</div>
