{% extends "layout.html" %}

{% block title %}Whoops!{% endblock %}
{% block subtitle %}Something went wrong.{% endblock %}
{% block panels %}
<div class="column">
    <section class="panel">
        <div class="panel-block">
            <p>
                Please file bugs on the <a href="https://github.com/glotzerlab/signac-dashboard/issues">signac-dashboard issue tracker</a>.
            </p>
        </div>
    </section>
</div>
{% endblock %}
