{% extends "layout.html" %}

{% block title %}Settings{% endblock %}
{% block subtitle %}Configure the dashboard{% endblock %}
{% block panels %}
<div class="column">
    <section class="panel">
        <div class="panel-block">
            <p>
                ...options...
            </p>
        </div>
    </section>
</div>
{% endblock %}
