{% extends "layout.html" %}

{% block title %}{{ g.title }}{% endblock %}
{% block subtitle %}{{ g.subtitle }}{% endblock %}
{% block module_selector %}{% endblock module_selector%}
{% block panels %}
{% if g.jobs | length > 0 %}
<div class="column">
    <section class="panel">
        <div class="panel-block">
            <ul>
                {% for job_details in g.jobs %}
                <li>
                    <a href="{{ url_for('show_job', jobid=job_details.job._id) }}">{{ job_details.title }} &mdash; {{ job_details.subtitle }}</a>
                </li>
                {% endfor %}
            </ul>
        </div>
    </section>
</div>
{% endif %}
{% endblock %}
